import * as cxapi from '@aws-cdk/cx-api';
import { ToolkitServices } from '../../../toolkit/private';
import { ActionAwareIoHost } from '../../io/private';
import type { AppSynthOptions } from '../source-builder';
export { guessExecutable } from '../../../api/aws-cdk';
type Env = {
    [key: string]: string;
};
type Context = {
    [key: string]: any;
};
/**
 * Turn the given optional output directory into a fixed output directory
 */
export declare function determineOutputDirectory(outdir?: string): string;
/**
 * If we don't have region/account defined in context, we fall back to the default SDK behavior
 * where region is retrieved from ~/.aws/config and account is based on default credentials provider
 * chain and then STS is queried.
 *
 * This is done opportunistically: for example, if we can't access STS for some reason or the region
 * is not configured, the context value will be 'null' and there could failures down the line. In
 * some cases, synthesis does not require region/account information at all, so that might be perfectly
 * fine in certain scenarios.
 *
 * @param context The context key/value bash.
 */
export declare function prepareDefaultEnvironment(services: ToolkitServices, props?: {
    outdir?: string;
}): Promise<Env>;
/**
 * Run code from a different working directory
 */
export declare function changeDir<T>(block: () => Promise<T>, workingDir?: string): Promise<T>;
/**
 * Run code with additional environment variables
 */
export declare function withEnv<T>(env: Env | undefined, block: () => Promise<T>): Promise<T>;
/**
 * Run code with context setup inside the environment
 */
export declare function withContext<T>(inputContext: Context, env: Env, synthOpts: AppSynthOptions | undefined, block: (env: Env, context: Context) => Promise<T>): Promise<T>;
/**
 * Checks if a given assembly supports context overflow, warn otherwise.
 *
 * @param assembly the assembly to check
 */
export declare function checkContextOverflowSupport(assembly: cxapi.CloudAssembly, ioHost: ActionAwareIoHost): Promise<void>;
/**
 * Safely create an assembly from a cloud assembly directory
 */
export declare function assemblyFromDirectory(assemblyDir: string, ioHost: ActionAwareIoHost): Promise<cxapi.CloudAssembly>;
